import {devNavigation} from '../../../../../src/shared/utils/navigation.utils';
import * as utils from '../../../../utils';

describe('Exceedance Explorer Application', () => {
  beforeEach(() => {
    cy.viewport('macbook-16');
    cy.visit('/dev/math/exceedance-explorer');
  });

  describe('Check nshmp-template', () => {
    utils.hasNshmpTemplate(devNavigation());
  });

  describe('Application', () => {
    utils.hasControlPanel();
    utils.hasPlotContent();
    utils.toggleControlPanel();
    utils.togglePlotPanel();
    utils.toggleSettingPanel();
    utils.changePlotSettings('.exceedance-plot', '.exceedance-settings');

    it('Has default plot', () => {
      cy.get('nshmp-template-plot-content')
        .find('plotly-plot')
        .should('be.visible');
    });

    it('Has control panel form fields', () => {
      setControlPanel();
    });

    it('Adds and removes curve from plot', () => {
      const buttons: utils.ControlPanelButtons = {
        hasResetButton: true,
        hasServiceCallButton: false,
        hasSubmitButton: true,
      };
      utils.controlPanelButtonsNotEnabled(buttons);

      setControlPanel();

      utils.submitFormCheckPlot({
        intercept: false,
        plotClass: '.exceedance-plot',
      });

      utils.controlPanelButtonsEnabled(buttons);
    });
  });
});

function setControlPanel() {
  utils.setInput('.median-input', '2.0');
  utils.setInput('.sigma-input', '0.5');
  utils.setInput('.rate-input', '1.0');
  cy.get('.truncation-checkbox').find('input').should('be.checked');
  utils.setInput('.truncation-level-input', '3.0');
}
