import 'cypress';

import {hasDownloadedFile} from './utils';

export interface ControlPanelButtons {
  hasResetButton: boolean;
  hasServiceCallButton: boolean;
  hasSubmitButton: boolean;
}

export function controlPanelButtonsEnabled(buttons: ControlPanelButtons) {
  cy.get('nshmp-lib-control-panel-buttons').find('.form-buttons').as('buttons');

  if (buttons.hasResetButton) {
    cy.get('@buttons')
      .find('.reset-button')
      .should('be.visible')
      .find('button')
      .should('be.enabled');
  }

  if (buttons.hasServiceCallButton) {
    cy.get('@buttons')
      .find('.service-button')
      .should('be.visible')
      .find('button')
      .should('be.enabled')
      .click();

    hasServiceCallPopUp();
    cy.get('body').click();
  }

  if (buttons.hasSubmitButton) {
    cy.get('@buttons')
      .find('.submit-button')
      .should('be.visible')
      .find('button')
      .should('be.enabled');
  }
}

export function controlPanelButtonsNotEnabled(buttons: ControlPanelButtons) {
  cy.get('nshmp-lib-control-panel-buttons').find('.form-buttons').as('buttons');

  if (buttons.hasResetButton) {
    cy.get('@buttons')
      .find('.reset-button')
      .should('be.visible')
      .should('not.be.enabled');
  }

  if (buttons.hasServiceCallButton) {
    cy.get('@buttons')
      .find('.service-button')
      .should('be.visible')
      .should('not.be.enabled');
  }

  if (buttons.hasSubmitButton) {
    cy.get('@buttons')
      .find('.submit-button')
      .should('be.visible')
      .should('not.be.enabled');
  }
}

export function exportDataTableNotExist() {
  cy.get('nshmp-lib-export-data-table').should('not.exist');
}

export function dataTableNotExist() {
  cy.get('nshmp-lib-data-table').should('not.exist');
}

export function hasExportDataTable(filename: string) {
  cy.get('nshmp-lib-export-data-table')
    .find('button')
    .should('be.enabled')
    .click();

  hasDownloadedFile(filename);
}

export function hasDataTable() {
  cy.get('nshmp-lib-data-table')
    .find('table')
    .find('td')
    .should('have.length.greaterThan', 1);
}

export function hasServiceCallPopUp() {
  cy.get('nshmp-lib-url-bottom-sheet').should('be.visible');
}
