import 'cypress';

import * as utils from './nshmp-template.utils';

const testText = 'Test Text';

type Axis = 'x' | 'y';

export function changePlotSettings(plotClass: string, settingsClass: string) {
  describe(`Change plot settings [plot ${plotClass}, settings ${settingsClass}]`, () => {
    beforeEach(() => {
      utils.clickSettingsPanel();
      cy.get('nshmp-template-settings')
        .find(settingsClass)
        .scrollIntoView()
        .as('plot-settings');
      cy.get('nshmp-template-plot-content')
        .find(plotClass)
        .scrollIntoView()
        .as('plot');
    });

    it('Plot title change', () => {
      cy.get('@plot-settings')
        .find('.title-input')
        .scrollIntoView()
        .should('be.visible')
        .find('input')
        .clear()
        .type(testText)
        .should('have.value', testText);

      cy.get('@plot').contains('text', testText).should('be.visible');

      cy.get('@plot-settings')
        .find('.title-font-size-input')
        .scrollIntoView()
        .should('be.visible')
        .find('input')
        .clear()
        .type('20')
        .should('have.value', '20');

      cy.get('@plot')
        .contains('text', testText)
        .should('have.css', 'font-size', '20px');
    });

    it('Aspect Ratio change', () => {
      cy.get('@plot-settings')
        .find('.plot-aspect-ratio-input')
        .scrollIntoView()
        .should('be.visible')
        .find('input')
        .clear()
        .type('16:9')
        .should('have.value', '16:9');
    });

    it('X-Axis title change', () => {
      axisTitleChange('x');
    });

    it('X-Axis axis change', () => {
      axisChange('x');
    });

    it('X axis number of tick marks change', () => {
      axisTickMarkNumberChange('x');
    });

    it('Y-Axis title change', () => {
      axisTitleChange('y');
    });

    it('Y-Axis axis change', () => {
      axisChange('y');
    });

    it('Y axis number of tick marks change', () => {
      axisTickMarkNumberChange('y');
    });

    it('Reset plot settings', () => {
      cy.get('nshmp-template-settings')
        .find('.form-buttons')
        .contains('button', 'Reset')
        .as('reset-button')
        .should('be.visible')
        .should('not.be.enabled');

      cy.get('@plot-settings')
        .find('.title-input')
        .find('input')
        .then(originalInput => {
          cy.get('@plot-settings')
            .find('.title-input')
            .find('input')
            .clear()
            .type(testText)
            .should('have.value', testText);

          cy.get('@reset-button').should('be.enabled').click();

          cy.get('@plot-settings')
            .find('.title-input')
            .find('input')
            .should(resetInput => {
              expect(originalInput.text()).to.equal(resetInput.text());
            });
        });
    });
  });
}

function axisChange(axis: Axis) {
  const axisClass = axis === 'x' ? '.x-axis-settings' : '.y-axis-settings';
  const axisLayerClass =
    axis === 'x' ? '.xaxislayer-above' : '.yaxislayer-above';

  cy.get('@plot-settings')
    .find(axisClass)
    .find('mat-button-toggle-group')
    .scrollIntoView()
    .as('axis-toggles')
    .contains('button', 'Log')
    .should('be.visible')
    .click()
    .get('@plot')
    .find(axisLayerClass)
    .then(logTicks => {
      cy.get('@axis-toggles')
        .contains('button', 'Linear')
        .scrollIntoView()
        .should('be.visible')
        .click()
        .get('@plot')
        .find(axisLayerClass)
        .should(linearTicks => {
          expect(logTicks).to.not.equal(linearTicks);
        });
    });
}

function axisTickMarkNumberChange(axis: Axis) {
  const axisClass = axis === 'x' ? '.x-axis-settings' : '.y-axis-settings';

  cy.get('@plot-settings')
    .find(axisClass)
    .scrollIntoView()
    .should('be.visible')
    .find('.axis-nticks')
    .find('input')
    .clear()
    .type('20')
    .should('have.value', '20');
}

function axisTitleChange(axis: Axis) {
  const axisClass = axis === 'x' ? '.x-axis-settings' : '.y-axis-settings';

  cy.get('@plot-settings')
    .find(axisClass)
    .scrollIntoView()
    .should('be.visible')
    .find('.axis-title-input')
    .find('input')
    .clear()
    .type(testText)
    .should('have.value', testText);

  cy.get('@plot').contains('text', testText).should('be.visible');

  cy.get('@plot-settings')
    .find(axisClass)
    .scrollIntoView()
    .should('be.visible')
    .find('.axis-title-font-size-input')
    .find('input')
    .clear()
    .type('20')
    .should('have.value', '20');

  cy.get('@plot')
    .contains('text', testText)
    .should('have.css', 'font-size', '20px');
}
