import {Routes} from '@angular/router';

import {designMapsRoutes} from './designmaps/design-maps.routes';
import {devRoutes} from './dev/dev.routes';
import {errorRoutes} from './error-pages/error-pages.routes';
import {gmmRoutes} from './gmm/gmm.routes';
import {hazardRoutes} from './hazard/hazard.routes';
import {sourceRoutes} from './source/source.routes';

/**
 * USGS Earthquake Hazard Toolbox routes
 */
const routes: Routes = [
  // Main dashboard application
  {
    loadComponent: () =>
      import('./dashboard/app.component').then(com => com.AppComponent),
    path: '',
  },
  // Design maps applications
  {
    children: designMapsRoutes(),
    path: 'designmaps',
  },
  // Development applications
  {
    children: devRoutes(),
    path: 'dev',
  },
  // Ground motion model applications
  {
    children: gmmRoutes(),
    path: 'gmm',
  },
  // Hazard applications
  {
    children: hazardRoutes(),
    path: 'hazard',
  },
  // Source model applications
  {
    children: sourceRoutes(),
    path: 'source',
  },
  // Services application
  {
    loadComponent: () =>
      import('./services/app.component').then(com => com.AppComponent),
    path: 'services',
  },
  // Error pages for reverse proxy errors
  {
    children: errorRoutes(),
    path: 'error-pages',
  },
  // Catch all
  {
    path: '**',
    redirectTo: '',
  },
];

/**
 * Return USGS earthquake hazard toolbox routes.
 */
export function appRoutes(): Routes {
  return routes;
}
