import {Component, computed, Signal} from '@angular/core';
import {MatDivider} from '@angular/material/divider';
import {MatExpansionModule} from '@angular/material/expansion';
import {
  NshmpLibNgDataTableComponent,
  NshmpLibNgExportDataTableComponent,
  TableData,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {NshmpPlot, plotUtils} from '@ghsc/nshmp-lib-ng/plot';
import {PlotData} from 'plotly.js';

import {AppService} from '../../services/app.service';

interface PlotTable {
  filename: string;
  plot: NshmpPlot;
  tableData: TableData[];
}

@Component({
  imports: [
    MatExpansionModule,
    NshmpLibNgDataTableComponent,
    NshmpLibNgExportDataTableComponent,
    MatDivider,
  ],
  selector: 'app-data',
  standalone: true,
  styleUrl: './data.component.scss',
  templateUrl: './data.component.html',
})
export class DataComponent {
  derivativeFragility = computed(() => {
    const plot = this.service.plots().derivativeFragility;
    return this.plotTable(plot, plot.plotData.data);
  });

  fragility = computed(() => {
    const plot = this.service.plots().fragility;
    // Remove horizontal and vertical lines
    const data = [...plot.plotData.data].slice(0, -4);
    return this.plotTable(plot, data);
  });

  hazard = computed(() => {
    const plot = this.service.plots().hazard;
    // Remove vertical and horizontal lines
    const data = [...plot.plotData.data].shift();
    return this.plotTable(plot, [data], false);
  });

  hazardFragility = computed(() => {
    const plot = this.service.plots().hazardFragility;
    return this.plotTable(plot, plot.plotData.data);
  });

  integralHazardFragility = computed(() => {
    const plot = this.service.plots().integralHazardFragility;
    // Remove vertical and horizontal lines
    const data = [...plot.plotData.data].slice(0, -1);
    return this.plotTable(plot, data);
  });

  plots: Signal<PlotTable>[] = [
    this.hazard,
    this.fragility,
    this.derivativeFragility,
    this.hazardFragility,
    this.integralHazardFragility,
  ];

  constructor(private service: AppService) {}

  private plotTable(
    nshmpPlot: NshmpPlot,
    data: Partial<PlotData>[],
    addLabel = true
  ): PlotTable {
    const plot: NshmpPlot = {
      ...nshmpPlot,
      plotData: {
        ...nshmpPlot.plotData,
        data,
      },
    };

    let tableData: TableData[] = [];

    if (!data.includes(undefined)) {
      tableData = plotUtils.plotDataToTableData(plot, {
        addLabel,
        xValueFormat: (val: number) => val.toFixed(4),
        yValueFormat: (val: number) => val.toExponential(4),
      });
    }

    return {
      filename: `${plot.label.toLowerCase()}.csv`,
      plot,
      tableData,
    };
  }
}
