import {Component, computed, Signal} from '@angular/core';
import {MatExpansionModule} from '@angular/material/expansion';
import {
  NshmpLibNgPlotResetPlotSettingComponent,
  NshmpLibNgPlotSettingsComponent,
  NshmpPlot,
  NshmpPlotSettings,
} from '@ghsc/nshmp-lib-ng/plot';

import {AppService} from '../../services/app.service';

interface PlotSetting {
  defaultPlotSetting: NshmpPlotSettings;
  plot: NshmpPlot;
  updatePlot: (plot: NshmpPlot) => void;
}

@Component({
  imports: [
    MatExpansionModule,
    NshmpLibNgPlotResetPlotSettingComponent,
    NshmpLibNgPlotSettingsComponent,
  ],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  plots: Signal<PlotSetting[]> = computed(() => {
    const plots = this.service.plots();
    const defaultPlots = this.service.defaultPlots();

    return [
      {
        defaultPlotSetting: defaultPlots.hazard.settingsForm.getRawValue(),
        plot: plots.hazard,
        updatePlot: plot => this.updateHazard(plot),
      },
      {
        defaultPlotSetting: defaultPlots.fragility.settingsForm.getRawValue(),
        plot: plots.fragility,
        updatePlot: plot => this.updateFragility(plot),
      },
      {
        defaultPlotSetting:
          defaultPlots.derivativeFragility.settingsForm.getRawValue(),
        plot: plots.derivativeFragility,
        updatePlot: plot => this.updateDerivativeFragility(plot),
      },
      {
        defaultPlotSetting:
          defaultPlots.hazardFragility.settingsForm.getRawValue(),
        plot: plots.hazardFragility,
        updatePlot: plot => this.updateHazardFragility(plot),
      },
      {
        defaultPlotSetting:
          defaultPlots.integralHazardFragility.settingsForm.getRawValue(),
        plot: plots.integralHazardFragility,
        updatePlot: plot => this.updateIntegral(plot),
      },
    ];
  });

  constructor(public service: AppService) {}

  updateHazard(hazard: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        hazard,
      },
    });
  }

  updateFragility(fragility: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        fragility,
      },
    });
  }

  updateDerivativeFragility(derivativeFragility: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        derivativeFragility,
      },
    });
  }

  updateHazardFragility(hazardFragility: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        hazardFragility,
      },
    });
  }

  updateIntegral(integralHazardFragility: NshmpPlot): void {
    this.service.updateState({
      plots: {
        ...this.service.plots(),
        integralHazardFragility,
      },
    });
  }
}
