import {Component, computed} from '@angular/core';
import {MatListModule} from '@angular/material/list';
import {
  NshmpLibNgDataTableComponent,
  TableData,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {RiskTargets} from '@ghsc/nshmp-utils-ts/libs/erp/rtgm';

import {AppService} from '../../services/app.service';

@Component({
  imports: [MatListModule, NshmpLibNgDataTableComponent],
  selector: 'app-risk-targets',
  standalone: true,
  styleUrl: './risk-targets.component.scss',
  templateUrl: './risk-targets.component.html',
})
export class RiskTargetsComponent {
  riskTargets = computed(
    () => this.service.serviceResponse()?.response.riskTargets
  );

  constructor(private service: AppService) {}

  tableData(riskTargets: RiskTargets): TableData[] {
    if (riskTargets === undefined) {
      return [];
    }

    return [
      {
        td: [`${riskTargets.UH_retPeriod.toPrecision(4)} years`],
        th: 'Initial target return period',
      },
      {
        td: [riskTargets.beta.toPrecision(4)],
        th: 'Standard deviation of fragility curve',
      },
      {
        td: [riskTargets.condCollapseProb.toPrecision(4)],
        th: 'Target conditional collapse fragility percentile',
      },
      {
        td: [`${riskTargets.riskTgt_Annual.toExponential(4)} yr^-1`],
        th: 'Target Annualized collapse risk',
      },
      {
        td: [riskTargets.tgtCollapseRisk_T.toPrecision(4)],
        th: 'Target risk of collapse over the specified time horizon',
      },
      {
        td: [`${riskTargets.timeHorizon_Yr} years`],
        th: 'Time horizon over which collapse risk is to be determined',
      },
    ];
  }
}
