import {Component, OnInit} from '@angular/core';
import {NshmpLibNgAboutPageComponent} from '@ghsc/nshmp-lib-ng/about';
import {NshmpLibNgTemplateComponent} from '@ghsc/nshmp-lib-ng/nshmp';
import {
  NshmpTemplateContentContainerComponent,
  NshmpTemplateControlPanelComponent,
  NshmpTemplatePlotContentComponent,
} from '@ghsc/nshmp-template';
import {devApps} from 'projects/nshmp-apps/src/shared/utils/applications.utils';
import {devNavigation} from 'projects/nshmp-apps/src/shared/utils/navigation.utils';

import {AboutComponent} from './components/about/about.component';
import {ContentComponent} from './components/content/content.component';
import {ControlPanelComponent} from './components/control-panel/control-panel.component';
import {AppService} from './services/app.service';

/**
 * Application to get logs from running hazard jobs on AWS.
 *
 * Services called:
 *  - {@link https://earthquake.usgs.gov/ws/nshmp/hazard-runs/nshmp-haz-logs}
 *  - {@link https://earthquake.usgs.gov/ws/nshmp/hazard-runs/jobs}
 *  - {@link https://earthquake.usgs.gov/ws/nshmp/hazard-runs/terminate-job}
 */
@Component({
  imports: [
    NshmpLibNgTemplateComponent,
    NshmpTemplateContentContainerComponent,
    NshmpTemplateControlPanelComponent,
    NshmpTemplatePlotContentComponent,
    NshmpLibNgAboutPageComponent,
    ControlPanelComponent,
    ContentComponent,
    AboutComponent,
  ],
  selector: 'app-app',
  standalone: true,
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent implements OnInit {
  /** Navigation list for menu */
  navigationList = devNavigation();
  /** Application title */
  title = devApps().aws.checkHazJobs.display;

  constructor(private service: AppService) {}

  ngOnInit() {
    this.service.init();
  }
}
