import {AsyncPipe, NgClass} from '@angular/common';
import {Component} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatButton} from '@angular/material/button';
import {MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {NshmpService} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';

/**
 * Check hazard job logs control panel.
 *
 * Control panel to get AWS job id and call the logs service.
 */
@Component({
  imports: [
    MatFormField,
    MatLabel,
    MatInput,
    NgClass,
    MatButton,
    AsyncPipe,
    ReactiveFormsModule,
  ],
  selector: 'app-control-panel',
  standalone: true,
  styleUrl: './control-panel.component.scss',
  templateUrl: './control-panel.component.html',
})
export class ControlPanelComponent {
  /** Form control state */
  form = this.service.formGroup;
  /** Log service response */
  logResponse = this.service.serviceResponse;

  constructor(
    public service: AppService,
    public nshmpService: NshmpService
  ) {}

  /**
   * On form submit.
   */
  onSubmit(): void {
    this.service.callService();
    this.nshmpService.selectPlotControl();
  }
}
