import {Component, computed} from '@angular/core';
import {MatCard, MatCardContent, MatCardTitle} from '@angular/material/card';
import {MatDivider} from '@angular/material/divider';
import {
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle,
} from '@angular/material/expansion';
import {MatList, MatListItem} from '@angular/material/list';
import {MatPaginator, PageEvent} from '@angular/material/paginator';
import {RouterLink} from '@angular/router';
import {YamlPipe} from '@ghsc/nshmp-lib-ng/aws';

import {AppService} from '../../services/app.service';

/**
 * Main application content showing AWS hazard run history for single job id or email.
 *
 * Job results are listed in Angular material paginator.
 *
 * @see https://material.angular.io/components/paginator
 */
@Component({
  imports: [
    MatPaginator,
    MatCard,
    MatCardTitle,
    MatDivider,
    MatCardContent,
    RouterLink,
    MatExpansionPanel,
    MatExpansionPanelHeader,
    MatExpansionPanelTitle,
    MatList,
    MatListItem,
    YamlPipe,
  ],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  /** Number of results per page */
  pageSize = 10;

  /** List of results for current page  */
  historySliced = computed(() =>
    this.service.jobHistory().slice(0, this.pageSize)
  );

  constructor(public service: AppService) {}

  /**
   * Handle page events.
   *
   * @param event The page event
   */
  onPage(event: PageEvent) {
    this.sliceJobInfoList(event.pageIndex, event.pageSize);
  }

  /**
   * Get results for current page.
   *
   * @param pageIndex The page index
   * @param pageSize The page size
   */
  private sliceJobInfoList(pageIndex: number, pageSize: number) {
    this.historySliced = computed(() =>
      this.service
        .jobHistory()
        .slice(pageIndex * pageSize, (pageIndex + 1) * pageSize)
    );
  }
}
