import {AsyncPipe, NgClass} from '@angular/common';
import {Component, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatButton} from '@angular/material/button';
import {MatOption} from '@angular/material/core';
import {MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {MatSelect} from '@angular/material/select';
import {JobStatus} from '@ghsc/nshmp-lib-ng/aws';
import {NshmpService, nshmpUtils} from '@ghsc/nshmp-lib-ng/nshmp';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

/**
 * Application control panel to get values to call service.
 */
@Component({
  imports: [
    MatFormField,
    MatLabel,
    MatInput,
    MatSelect,
    MatOption,
    NgClass,
    MatButton,
    AsyncPipe,
    ReactiveFormsModule,
  ],
  selector: 'app-control-panel',
  standalone: true,
  styleUrl: './control-panel.component.scss',
  templateUrl: './control-panel.component.html',
})
export class ControlPanelComponent implements OnInit, OnDestroy {
  /** Form controll state */
  form = this.service.formGroup;
  /** List of job status types */
  jobStatuses = Object.values(JobStatus);
  /** Place holder for select menu */
  selectPlaceHolder = nshmpUtils.selectPlaceHolder();

  private filterSubscription = new Subscription();

  constructor(
    public nshmpService: NshmpService,
    private service: AppService
  ) {}

  ngOnInit(): void {
    this.filterSubscription = this.form.controls.filter.valueChanges.subscribe(
      () => this.service.filterHistory()
    );
  }

  ngOnDestroy(): void {
    this.filterSubscription.unsubscribe();
  }

  /**
   * On form submit.
   */
  onSubmit(): void {
    this.service.callService();
    this.nshmpService.selectPlotControl();
  }
}
