import {Component, computed, OnDestroy} from '@angular/core';
import {
  MatAccordion,
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle,
} from '@angular/material/expansion';
import {
  NshmpLibNgPlotResetPlotSettingsComponent,
  NshmpLibNgPlotSettingsComponent,
  NshmpPlot,
  PlotSettingsPanel,
} from '@ghsc/nshmp-lib-ng/plot';
import {Subscription} from 'rxjs';

import {Plots} from '../../models/state.model';
import {AppService} from '../../services/app.service';

@Component({
  imports: [
    NshmpLibNgPlotResetPlotSettingsComponent,
    NshmpLibNgPlotSettingsComponent,
    MatAccordion,
    MatExpansionPanel,
    MatExpansionPanelHeader,
    MatExpansionPanelTitle,
  ],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent implements OnDestroy {
  /** Ground motion plot */
  groundMotionPlot = computed(() => {
    this.settingsFormSubscription?.unsubscribe();
    const plot = this.service.state().plots.get(Plots.GROUND_MOTION);

    this.settingsFormSubscription = plot.settingsForm.valueChanges.subscribe(
      () => {
        this.resetDisabled =
          plot.settingsForm.pristine && plot.settingsForm.untouched;
      }
    );

    return plot;
  });

  panels: PlotSettingsPanel[] = [
    {
      id: Plots.GROUND_MOTION,
      plot: this.groundMotionPlot,
      title: 'Ground Motion Plot Settings',
    },
  ];

  resetDisabled = true;
  private settingsFormSubscription = new Subscription();

  constructor(public service: AppService) {}

  ngOnDestroy(): void {
    this.settingsFormSubscription.unsubscribe();
  }

  updatePlot(plot: NshmpPlot): void {
    this.service.updatePlot(plot, Plots.GROUND_MOTION);
  }
}
