import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {
  MatAccordion,
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle,
} from '@angular/material/expansion';
import {
  NshmpLibNgPlotSettingsComponent,
  NshmpPlot,
  PlotSettingsPanel,
} from '@ghsc/nshmp-lib-ng/plot';

import {Plots} from '../../models/state.model';
import {AppService} from '../../services/app.service';

/**
 * Settings for all plots.
 */
@Component({
  imports: [
    NshmpLibNgPlotSettingsComponent,
    MatAccordion,
    MatExpansionPanel,
    MatExpansionPanelHeader,
    MatExpansionPanelTitle,
    AsyncPipe,
  ],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  /** Hazard plot data */
  private hazardPlot = computed(() => this.service.plots().get(Plots.HAZARD));

  /** Hazard components plot data */
  private hazardComponentsPlot = computed(() =>
    this.service.plots().get(Plots.HAZARD_COMPONENTS)
  );

  /** Hazard % diff plot data */
  private hazardDiffPlot = computed(() =>
    this.service.plots().get(Plots.HAZARD_DIFFERENCES)
  );

  /** Spectra components plot data */
  private spectraComponentsPlot = computed(() =>
    this.service.plots().get(Plots.SPECTRUM_COMPONENTS)
  );

  /** Spectra % diff plot data */
  private spectraDiffPlot = computed(() =>
    this.service.plots().get(Plots.SPECTRUM_DIFFERENCES)
  );

  /** Spectra plot data */
  private spectraPlot = computed(() =>
    this.service.plots().get(Plots.SPECTRUM)
  );

  /** The panels with plot settings */
  panels: PlotSettingsPanel[] = [
    {
      id: Plots.HAZARD,
      plot: this.hazardPlot,
      title: 'Hazard Curves Plot Settings',
    },
    {
      id: Plots.HAZARD_DIFFERENCES,
      plot: this.hazardDiffPlot,
      title: 'Hazard % Difference Plot Settings',
    },
    {
      id: Plots.SPECTRUM,
      plot: this.spectraPlot,
      title: 'Spectra Plot Settings',
    },
    {
      id: Plots.SPECTRUM_DIFFERENCES,
      plot: this.spectraDiffPlot,
      title: 'Spectra % Difference Plot Settings',
    },
    {
      id: Plots.HAZARD_COMPONENTS,
      plot: this.hazardComponentsPlot,
      title: 'Hazard Component Curves Plot Settings',
    },
    {
      id: Plots.SPECTRUM_COMPONENTS,
      plot: this.spectraComponentsPlot,
      title: 'Spectra Component Curves Plot Settings',
    },
  ];

  constructor(private service: AppService) {}

  updatePlot(id: string, plot: NshmpPlot): void {
    const plots = new Map(this.service.state().plots);
    plots.set(id, plot);
    this.service.updateState({
      plots,
    });
  }
}
