import {AsyncPipe} from '@angular/common';
import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatCheckbox} from '@angular/material/checkbox';
import {MatError, MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {
  NshmpLibNgControlPanelButtonsComponent,
  NshmpService,
} from '@ghsc/nshmp-lib-ng/nshmp';
import {Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

/**
 * Control panel with form fields to plot exceedance.
 */
@Component({
  imports: [
    MatFormField,
    MatLabel,
    MatInput,
    MatError,
    MatCheckbox,
    AsyncPipe,
    NshmpLibNgControlPanelButtonsComponent,
    ReactiveFormsModule,
  ],
  selector: 'app-control-panel',
  standalone: true,
  styleUrl: './control-panel.component.scss',
  templateUrl: './control-panel.component.html',
})
export class ControlPanelComponent implements OnInit, OnDestroy {
  /** The form field bounds */
  formBounds = this.service.formBounds();

  /** Plot data state */
  data = computed(() => this.service.plot().plotData.data);
  /** Form field state */
  form = this.service.formGroup;

  private truncationSubscription = new Subscription();

  constructor(
    public service: AppService,
    private nshmpService: NshmpService
  ) {}

  ngOnInit(): void {
    this.truncationSubscription =
      this.form.controls.truncation.valueChanges.subscribe(truncation => {
        if (truncation) {
          this.form.controls.truncationLevel.enable();
        } else {
          this.form.controls.truncationLevel.disable();
        }
      });
  }

  ngOnDestroy(): void {
    this.truncationSubscription.unsubscribe();
  }

  /**
   * On form submit.
   */
  onSubmit(): void {
    this.service.callService();
    this.nshmpService.selectPlotControl();
  }
}
