import {AsyncPipe} from '@angular/common';
import {Component, computed, OnDestroy, OnInit} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {MatError, MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {combineLatest, Subscription} from 'rxjs';

import {AppService} from '../../services/app.service';

/**
 * Control panel form fields for GMM source parameters.
 */
@Component({
  imports: [
    MatLabel,
    MatFormField,
    MatInput,
    MatError,
    AsyncPipe,
    ReactiveFormsModule,
  ],
  selector: 'app-source-parameters',
  standalone: true,
  styleUrl: './source-parameters.component.scss',
  templateUrl: './source-parameters.component.html',
})
export class SourceParametersComponent implements OnInit, OnDestroy {
  /** Form controls state */
  controls = this.service.formGroup.controls;

  /** Control panel form field state */
  form = this.service.formGroup;

  /** Usage parameters */
  parameters = computed(() => this.service.usage()?.response.parameters);

  private valueSubscription = new Subscription();

  constructor(private service: AppService) {}

  ngOnInit(): void {
    combineLatest([
      this.controls.dip.valueChanges,
      this.controls.width.valueChanges,
      this.controls.zTor.valueChanges,
    ]).subscribe(() => this.service.resetState());
  }

  ngOnDestroy(): void {
    this.valueSubscription.unsubscribe();
  }
}
