import {AsyncPipe} from '@angular/common';
import {
  Component,
  computed,
  OnDestroy,
  OnInit,
  ViewEncapsulation,
} from '@angular/core';
import {ReactiveFormsModule} from '@angular/forms';
import {
  MatButtonToggle,
  MatButtonToggleGroup,
} from '@angular/material/button-toggle';
import {MatCheckbox} from '@angular/material/checkbox';
import {MatError, MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {
  GmmFormControlIds,
  MW_COMMON_VALUES,
  NshmpLibNgGmmMultiSelectComponent,
} from '@ghsc/nshmp-lib-ng/gmm';
import {combineLatest, Subscription} from 'rxjs';
import {map} from 'rxjs/operators';

import {AppService} from '../../services/app.service';

/**
 * Control panel form fields for GMM event parameters.
 */
@Component({
  encapsulation: ViewEncapsulation.None,
  imports: [
    NshmpLibNgGmmMultiSelectComponent,
    MatLabel,
    MatFormField,
    MatInput,
    MatError,
    MatButtonToggleGroup,
    MatButtonToggle,
    MatCheckbox,
    AsyncPipe,
    ReactiveFormsModule,
  ],
  selector: 'app-event-parameters',
  standalone: true,
  styleUrl: './event-parameters.component.scss',
  templateUrl: './event-parameters.component.html',
})
export class EventParametersComponent implements OnInit, OnDestroy {
  /** Common Vs30 values */
  MwCommonValues = MW_COMMON_VALUES;

  /** Control panel form field state */
  form = this.service.formGroup;

  /** Whether magnitudes are multi-selectable */
  MwMultiple$ =
    this.service.formGroup.controls.multiSelectableParam.valueChanges.pipe(
      map(
        multiSelectableParam =>
          multiSelectableParam.toString() === GmmFormControlIds.MW.toString()
      )
    );

  /** Usage parameters */
  parameters = computed(() => this.service.usage()?.response.parameters);

  private controls = this.form.controls;

  private subs: Subscription[] = [];

  constructor(private service: AppService) {}

  ngOnInit(): void {
    this.subs.push(
      combineLatest([
        this.controls.Mw.valueChanges,
        this.controls.rake.valueChanges,
        this.controls.rakeButton.valueChanges,
        this.controls.zHyp.valueChanges,
      ]).subscribe(() => this.service.resetState())
    );

    this.subs.push(
      this.controls.zHypCentered.valueChanges.subscribe(() =>
        this.onZHypCentered()
      )
    );
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }

  private onZHypCentered(): void {
    if (this.form.getRawValue().zHypCentered) {
      this.controls.zHyp.disable();
    } else {
      this.controls.zHyp.enable();
    }

    this.service.calcHypocenterDepth(this.form);
  }
}
