import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {gmmUtils} from '@ghsc/nshmp-lib-ng/gmm';
import {
  NshmpLibNgPlotResetPlotSettingsComponent,
  NshmpLibNgPlotSettingsComponent,
} from '@ghsc/nshmp-lib-ng/plot';

import {SpectraPlot} from '../../models/spectra-plot.model';
import {AppService} from '../../services/app.service';

/**
 * Plot settings form fields.
 */
@Component({
  imports: [
    NshmpLibNgPlotResetPlotSettingsComponent,
    NshmpLibNgPlotSettingsComponent,
    AsyncPipe,
  ],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  PlotIds = gmmUtils.PlotType;

  /** Mean plot state */
  spectraPlot = this.service.spectraPlotState;

  /** Mean plot settings */
  spectraPlotSettings = computed(
    () => this.service.spectraPlotState().settingsForm
  );

  /** Sigma plot state */
  sigmaPlot = this.service.sigmaPlotState;

  /** Sigma plot settings */
  sigmaPlotSettings = computed(
    () => this.service.sigmaPlotState().settingsForm
  );

  constructor(public service: AppService) {}

  updatePlot(id: string, plot: SpectraPlot): void {
    const plots = new Map(this.service.state().plots);
    plots.set(id, plot);
    this.service.updateState({
      plots,
    });
  }
}
