import {AsyncPipe} from '@angular/common';
import {Component, computed} from '@angular/core';
import {MatDivider} from '@angular/material/divider';
import {MatExpansionModule} from '@angular/material/expansion';
import {NshmpLibNgAppMetadataComponent} from '@ghsc/nshmp-lib-ng/nshmp';

import {AppService} from '../../services/app.service';
import {DisaggContributorsComponent} from '../disagg-contributors/disagg-contributors.component';
import {DisaggDataComponent} from '../disagg-data/disagg-data.component';
import {DisaggSummaryComponent} from '../disagg-summary/disagg-summary.component';
import {GeoDisaggComponent} from '../geo-disagg/geo-disagg.component';
import {ParameterSummaryComponent} from '../parameter-summary/parameter-summary.component';
import {PlotsComponent} from '../plots/plots.component';

/**
 * Main content for application with:
 *  - disagg plot: {@link ../plots/plots.component.ts}
 *  - parameter summary: {@link ../parameter-summary/parameter-summary.component.ts}
 *  - disagg summary: {@link ../disagg-summary/disagg-summary.component.ts}
 *  - disagg contributions: {@link ../disagg-contributions/disagg-contributions.component.ts}
 */
@Component({
  imports: [
    MatExpansionModule,
    PlotsComponent,
    MatDivider,
    GeoDisaggComponent,
    ParameterSummaryComponent,
    NshmpLibNgAppMetadataComponent,
    DisaggSummaryComponent,
    DisaggContributorsComponent,
    DisaggDataComponent,
    AsyncPipe,
  ],
  selector: 'app-content',
  standalone: true,
  styleUrl: './content.component.scss',
  templateUrl: './content.component.html',
})
export class ContentComponent {
  componentData = this.service.componentData;
  /** Disaggregation data */
  disaggData = this.service.disaggData;
  formGroup = this.service.formGroup;

  hasData = computed(() => this.service.serviceResponse() !== null);

  /** Has geo disagg layers */
  hasLayers = computed(() => {
    const serviceResponse = this.service.serviceResponse();

    if (serviceResponse === null || serviceResponse === undefined) {
      return false;
    }

    const layers = serviceResponse.response.disaggs.find(disaggs =>
      disaggs.data.find(data =>
        data.sources.find(
          source => source.latitude !== null && source.longitude !== null
        )
      )
    );

    return layers !== undefined;
  });

  /** Repo metadata */
  repositories = computed(() => this.service.usage()?.metadata.repositories);

  constructor(private service: AppService) {}
}
