import {AsyncPipe} from '@angular/common';
import {Component, computed, Input} from '@angular/core';
import {MatButton} from '@angular/material/button';
import {MatDivider} from '@angular/material/divider';
import {
  DisaggComponentData,
  DisaggData,
} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/disagg-service';

import {AppService} from '../../services/app.service';

@Component({
  imports: [AsyncPipe, MatDivider, MatButton],
  selector: 'app-disagg-data',
  standalone: true,
  styleUrl: './disagg-data.component.scss',
  templateUrl: './disagg-data.component.html',
})
export class DisaggDataComponent {
  /** Disaggregation component data state */
  @Input({required: true})
  componentData: DisaggComponentData;

  @Input()
  showExportButton = true;

  metadata = computed(() => this.service.serviceResponse().response.metadata);

  constructor(public service: AppService) {}

  toBinData(data: DisaggData): string[] {
    const bins = this.service.serviceResponse().response.metadata.εbins;

    const binData = bins.map(
      bin => data.εdata.find(data => data.εbin === bin.id)?.value ?? 0
    );

    const total = binData.reduce((a, b) => a + b, 0);

    return [total, ...binData].map(num => num.toExponential(2));
  }

  epsilonKeys(): string[] {
    const keys = this.componentData.summary.find(
      data => data.name.toLowerCase() === 'epsilon keys'
    );

    return ['ALL_ε', ...keys.data.map(data => `${data.name}=${data.value}`)];
  }
}
