import {AsyncPipe} from '@angular/common';
import {Component} from '@angular/core';
import {MatExpansionModule} from '@angular/material/expansion';
import {HazardPlots} from '@ghsc/nshmp-lib-ng/hazard';
import {
  NshmpLibNgPlotResetPlotSettingsComponent,
  NshmpLibNgPlotSettingsComponent,
  NshmpPlot,
  PlotSettingsPanel,
} from '@ghsc/nshmp-lib-ng/plot';

import {AppService} from '../../services/app.service';

/**
 * Plot settings panel.
 */
@Component({
  imports: [
    NshmpLibNgPlotSettingsComponent,
    NshmpLibNgPlotResetPlotSettingsComponent,
    AsyncPipe,
    MatExpansionModule,
  ],
  selector: 'app-plot-settings-panel',
  standalone: true,
  styleUrl: './plot-settings-panel.component.scss',
  templateUrl: './plot-settings-panel.component.html',
})
export class PlotSettingsPanelComponent {
  /** Hazard plot state */
  private hazardPlot = this.service.hazardPlotState;
  /** Spectra plot state */
  private spectrumPlot = this.service.spectrumPlotState;

  /** Hazard plot settings */
  hazardSettings = this.service.hazardPlotSettings;
  /** Spectra plot settings */
  spectrumSettings = this.service.spectrumPlotSettings;

  panels: PlotSettingsPanel[] = [
    {
      id: HazardPlots.HAZARD,
      plot: this.hazardPlot,
      title: 'Hazard Curves Plot Settings',
    },
    {
      id: HazardPlots.SPECTRUM,
      plot: this.spectrumPlot,
      title: 'Spectra Plot Settings',
    },
  ];

  constructor(public service: AppService) {}

  updatePlot(id: string, plot: NshmpPlot): void {
    const plots = new Map(this.service.plots());
    plots.set(id, plot);
    this.service.updateState({
      plots,
    });
  }
}
