import {AsyncPipe} from '@angular/common';
import {Component} from '@angular/core';
import {MatList, MatListItem} from '@angular/material/list';
import {nshmpUtils} from '@ghsc/nshmp-lib-ng/nshmp';
import {SourceLogicTreesUsage} from '@ghsc/nshmp-utils-ts/libs/nshmp-haz/www/source-logic-trees-service';
import {
  sourceTypeToCapitalCase,
  tectonicSettingsToString,
} from '@ghsc/nshmp-utils-ts/libs/nshmp-lib/model';

import {ControlForm, MfdSource} from '../../models/control-form.model';
import {AppService} from '../../services/app.service';

/**
 * Summary of parameters entered, form field values to call service.
 */
@Component({
  imports: [MatList, MatListItem, AsyncPipe],
  selector: 'app-parameter-summary',
  standalone: true,
  styleUrl: './parameter-summary.component.scss',
  templateUrl: './parameter-summary.component.html',
})
export class ParameterSummaryComponent {
  /** Function to get display from a `Parameter` */
  toDisplay = nshmpUtils.parameterToDisplay;

  /** Form field state */
  formGroup = this.service.formGroup;

  /** Usage response state */
  usage = this.service.usage;

  constructor(public service: AppService) {}

  /**
   * Returns the source tree name.
   *
   * @param values Control panel form field values
   * @param usage Source logic trees usage
   */
  sourceTree(values: ControlForm, usage: SourceLogicTreesUsage): string {
    if (values.model === null || values.source === null || usage === null) {
      return '';
    }

    const source = values.source;

    const settingsTree = usage.response.trees.find(
      tree => tree.setting === source.tectonicSettings
    );
    const tree = settingsTree?.data?.find(
      data => data.type === source.sourceType
    );
    const data = tree?.data.find(info => info.id === values.sourceTree);

    return data ? `${data.name} (${values.sourceTree})` : '';
  }

  /**
   * Returns the source type name.
   *
   * @param source The MFD source
   * @returns
   */
  sourceType(source: MfdSource): string {
    return source === undefined || source === null
      ? ''
      : sourceTypeToCapitalCase(source.sourceType);
  }

  /**
   * Returns the tectonic setting name.
   *
   * @param source The MFD source
   * @returns
   */
  tectonicSetting(source: MfdSource): string {
    return source === undefined || source === null
      ? ''
      : tectonicSettingsToString(source.tectonicSettings);
  }
}
