import {AsyncPipe} from '@angular/common';
import {Component, OnDestroy, OnInit, ViewEncapsulation} from '@angular/core';
import {NshmpLibNgAboutPageComponent} from '@ghsc/nshmp-lib-ng/about';
import {NshmpLibNgHazardProvisionalModelComponent} from '@ghsc/nshmp-lib-ng/hazard';
import {NshmpLibNgTemplateComponent} from '@ghsc/nshmp-lib-ng/nshmp';
import {
  AppControlsService,
  NshmpTemplateContentContainerComponent,
  NshmpTemplateControlPanelComponent,
  NshmpTemplateMapContentComponent,
  NshmpTemplateSettingsComponent,
} from '@ghsc/nshmp-template';
import {apps} from 'projects/nshmp-apps/src/shared/utils/applications.utils';
import {navigation} from 'projects/nshmp-apps/src/shared/utils/navigation.utils';
import {Subscription} from 'rxjs';

import {AboutComponent} from './components/about/about.component';
import {ControlPanelComponent} from './components/control-panel/control-panel.component';
import {InfoPopupComponent} from './components/info-popup/info-popup.component';
import {MapComponent} from './components/map/map.component';
import {PlotSettingsPanelComponent} from './components/plot-settings-panel/plot-settings-panel.component';
import {AppService} from './services/app.service';

/**
 * Main entrypoint for the data mapping application.
 *
 * Show vairous layers associated with a NSHM using Leaflet.
 *
 * @see https://leafletjs.com/
 */
@Component({
  encapsulation: ViewEncapsulation.None,
  imports: [
    NshmpLibNgTemplateComponent,
    NshmpTemplateContentContainerComponent,
    NshmpTemplateControlPanelComponent,
    NshmpTemplateMapContentComponent,
    NshmpTemplateSettingsComponent,
    NshmpLibNgHazardProvisionalModelComponent,
    NshmpLibNgAboutPageComponent,
    ControlPanelComponent,
    MapComponent,
    PlotSettingsPanelComponent,
    InfoPopupComponent,
    AboutComponent,
    AsyncPipe,
  ],
  selector: 'app-app',
  standalone: true,
  styleUrl: './app.component.scss',
  templateUrl: './app.component.html',
})
export class AppComponent implements OnInit, OnDestroy {
  /** Subscirption on controls change */
  controlsSubscription: Subscription;
  /** Navigation list for meny */
  navigationList = navigation();
  /** Application title */
  title = apps().source.data.display;

  constructor(
    public service: AppService,
    private controlsService: AppControlsService
  ) {}

  ngOnInit() {
    this.service.init();

    this.controlsSubscription = this.controlsService.controlsChanged.subscribe(
      () => this.service.mapRedraw()
    );
  }

  ngOnDestroy(): void {
    this.controlsSubscription?.unsubscribe();
  }
}
