import {Applications, DevApplications} from '../models/applications.model';

/** Main application name */
export const TOOLBOX_NAME = 'USGS Earthquake Hazard Toolbox';

/**
 * Returns all application info.
 */
export function apps(): Applications {
  return {
    dashboard: {
      display: 'Dashboard',
      routerLink: '/',
    },
    designMaps: {
      rtgm: {
        display: 'Risk-Targeted Ground Motion',
        routerLink: '/designmaps/rtgm',
      },
    },
    gmm: {
      distance: {
        display: 'Ground Motion vs. Distance',
        routerLink: '/gmm/distance',
      },
      magnitude: {
        display: 'Ground Motion vs. Magnitude',
        routerLink: '/gmm/magnitude',
      },
      spectra: {
        display: 'Response Spectra',
        routerLink: '/gmm/spectra',
      },
    },
    hazard: {
      disagg: {
        display: 'Disaggregation',
        routerLink: '/hazard/disagg',
      },
      dynamic: {
        display: 'Hazard Curves (dynamic)',
        routerLink: '/hazard/dynamic',
      },
      static: {
        display: 'Hazard Curves (static)',
        routerLink: '/hazard/static',
      },
    },
    services: {
      display: 'Services',
      routerLink: '/services',
    },
    source: {
      data: {
        display: 'Model Maps',
        routerLink: '/source/model-maps',
      },
      mfd: {
        display: 'Magnitude Frequency Distribution',
        routerLink: '/source/mfd',
      },
    },
  };
}

/**
 * Returns all the dev application info.
 */
export function devApps(): DevApplications {
  return {
    aws: {
      checkHazJobs: {
        display: 'Check nshmp-haz Jobs',
        routerLink: '/dev/aws/check-haz-jobs',
      },
      hazJobHistory: {
        display: 'nshmp-haz Job History',
        routerLink: '/dev/aws/haz-job-history',
      },
      submitHazJobs: {
        display: 'Submit nshmp-haz Jobs',
        routerLink: '/dev/aws/submit-haz-jobs',
      },
      terminateHazJobs: {
        display: 'Terminate nshmp-haz Jobs',
        routerLink: '/dev/aws/terminate-haz-jobs',
      },
    },
    dashboard: {
      display: 'Development Dashboard',
      routerLink: '/dev',
    },
    exceedanceExplorer: {
      display: 'Exceedance Explorer',
      routerLink: '/dev/math/exceedance-explorer',
    },
    gmm: {
      hangingWallEffects: {
        display: 'Hanging Wall Effects',
        routerLink: '/dev/gmm/hanging-wall-effects',
      },
    },
    hazard: {
      dynamicCompare: {
        display: 'Dynamic Hazard Compare',
        routerLink: '/dev/hazard/dynamic-compare',
      },
    },
  };
}
