import {Navigation, NavigationList} from '@ghsc/nshmp-template';

import * as ApplicationsUtils from './applications.utils';

const APPS = ApplicationsUtils.apps();
const DEV_APPS = ApplicationsUtils.devApps();

/**
 * Returns the list of AWS applications.
 */
export function devAwsApps(): Navigation[] {
  return [
    DEV_APPS.aws.checkHazJobs,
    DEV_APPS.aws.hazJobHistory,
    DEV_APPS.aws.submitHazJobs,
    DEV_APPS.aws.terminateHazJobs,
  ];
}

/**
 * Returns the list development main applications.
 */
export function devMainApps(): Navigation[] {
  return [
    DEV_APPS.exceedanceExplorer,
    DEV_APPS.hazard.dynamicCompare,
    DEV_APPS.gmm.hangingWallEffects,
  ];
}

/**
 * Returns the drop down navigation menu for development applications.
 */
export function devNavigation(): NavigationList[] {
  const devNavigation: NavigationList[] = [
    {
      navigation: [DEV_APPS.dashboard, ...devMainApps()],
    },
    {
      navigation: devAwsApps(),
      subHeader: 'AWS',
    },
  ];

  return [...devNavigation];
}

/**
 * Returns the list of ground motion model applications.
 */
export function gmmApps(): Navigation[] {
  return [APPS.gmm.distance, APPS.gmm.magnitude, APPS.gmm.spectra];
}

/**
 * Returns the list of main applications.
 */
export function mainApps(): Navigation[] {
  return [
    APPS.hazard.disagg,
    APPS.hazard.dynamic,
    APPS.hazard.static,
    APPS.designMaps.rtgm,
    APPS.services,
  ];
}

/**
 * Returns drop down navigation menu of applications.
 */
export function navigation(): NavigationList[] {
  const navigation: NavigationList[] = [
    {
      navigation: [APPS.dashboard],
    },
    {
      navigation: mainApps(),
    },
    {
      navigation: sourceModelApps(),
      subHeader: 'Source Models',
    },
    {
      navigation: gmmApps(),
      subHeader: 'Ground Motion Models',
    },
  ];

  return [...navigation];
}

/**
 * Returns the list of source model applicaitons.
 */
export function sourceModelApps(): Navigation[] {
  return [APPS.source.data, APPS.source.mfd];
}
